@@ -1,21 +1,21 @@
 #' Default start value
 #' @export
-walsby_default_start_value_etr_max <- 100
+walsby_default_start_value_etr_max <- 49.70366
 
 #' Default start value
 #' @export
-walsby_default_start_value_alpha <- 0.4
+walsby_default_start_value_alpha <- 0.1228559
 
 #' Default start value
 #' @export
-walsby_default_start_value_beta <- -0.01
+walsby_default_start_value_beta <- -0.0008944076
 
 #' Walsby Regression for ETR I
 #'
 #' Fits a modified Walsby (1997) regression model without the respiration term, using Romoth (2019) naming conventions.
 #' Calculates \eqn{ETR_{max}} without accounting for photoinhibition.
 #'
-#' @param data A \code{data.table} from \code{read_dual_pam_data}.
+#' @param data A \code{data.table} from read function (e.g.\code{read_dual_pam_data}).
 #' @param etr_max_start_value Numeric. Initial value for \eqn{ETR_{max}}. Default: \code{etr_max_start_value_walsby_default}.
 #' @param alpha_start_value Numeric. Initial value for \eqn{\alpha}. Default: \code{alpha_start_value_walsby_default}.
 #' @param beta_start_value Numeric. Initial value for \eqn{\beta}. Default: \code{beta_start_value_walsby_default}.
@@ -26,7 +26,9 @@ walsby_default_start_value_beta <- -0.01
 #' @return A list containing:
 #' \itemize{
 #'   \item \code{etr_regression_data}: Predicted ETR values.
-#'   \item \code{sdiff}: Deviation between actual and predicted ETR.
+#'   \item \code{residual_sum_of_squares}: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.
+#'   \item \code{root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the root mean squared error.
+#'   \item \code{relative_root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.
 #'   \item \code{etr_max}: Maximum ETR (\eqn{ETR_{max}}).
 #'   \item \code{alpha}: Initial slope (\eqn{\alpha}).
 #'   \item \code{beta}: Photoinhibition factor (\eqn{\beta}).
@@ -56,7 +58,7 @@ walsby_generate_regression_ETR_I <- function(
   return(
     walsby_generate_regression_internal(
       data,
-      etr_I_type,
+      etr_1_type,
       etr_max_start_value,
       alpha_start_value,
       beta_start_value
@@ -69,7 +71,7 @@ walsby_generate_regression_ETR_I <- function(
 #' Fits a modified Walsby (1997) regression model without the respiration term, using Romoth (2019) naming conventions.
 #' Calculates \eqn{ETR_{max}} without accounting for photoinhibition.
 #'
-#' @param data A \code{data.table} from \code{read_dual_pam_data}.
+#' @param data A \code{data.table} from read function (e.g.\code{read_dual_pam_data}).
 #' @param etr_max_start_value Numeric. Initial value for \eqn{ETR_{max}}. Default: \code{etr_max_start_value_walsby_default}.
 #' @param alpha_start_value Numeric. Initial value for \eqn{\alpha}. Default: \code{alpha_start_value_walsby_default}.
 #' @param beta_start_value Numeric. Initial value for \eqn{\beta}. Default: \code{beta_start_value_walsby_default}.
@@ -80,7 +82,9 @@ walsby_generate_regression_ETR_I <- function(
 #' @return A list containing:
 #' \itemize{
 #'   \item \code{etr_regression_data}: Predicted ETR values.
-#'   \item \code{sdiff}: Deviation between actual and predicted ETR.
+#'   \item \code{residual_sum_of_squares}: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.
+#'   \item \code{root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the root mean squared error.
+#'   \item \code{relative_root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.
 #'   \item \code{etr_max}: Maximum ETR (\eqn{ETR_{max}}).
 #'   \item \code{alpha}: Initial slope (\eqn{\alpha}).
 #'   \item \code{beta}: Photoinhibition factor (\eqn{\beta}).
@@ -109,7 +113,7 @@ walsby_generate_regression_ETR_II <- function(
     beta_start_value = walsby_default_start_value_beta) {
   return(walsby_generate_regression_internal(
     data,
-    etr_II_type,
+    etr_2_type,
     etr_max_start_value,
     alpha_start_value,
     beta_start_value
@@ -145,9 +149,7 @@ walsby_generate_regression_internal <- function(
         stop("beta start value is not a valid number")
       }
 
-      data <- remove_det_row_by_etr(data, etr_type)
-
-      model <- minpack.lm::nlsLM(data[[etr_type]] ~ etr_max * (1 - exp((-alpha * PAR) / etr_max)) + beta * PAR,
+      model <- minpack.lm::nlsLM(data[[etr_type]] ~ etr_max * (1 - exp((-alpha * par) / etr_max)) + beta * par,
         data = data,
         start = list(
           etr_max = etr_max_start_value,
@@ -157,6 +159,8 @@ walsby_generate_regression_internal <- function(
         control = stats::nls.control(maxiter = 1000)
       )
 
+      residual_sum_of_squares <- model$m$deviance()
+
       abc <- stats::coef(model)
       etr_max <- abc[["etr_max"]]
       alpha <- abc[["alpha"]]
@@ -164,30 +168,25 @@ walsby_generate_regression_internal <- function(
 
       pars <- c()
       predictions <- c()
-      for (p in min(data$PAR):max(data$PAR)) {
+      for (p in min(data$par):max(data$par)) {
         pars <- c(pars, p)
         predictions <- c(predictions, etr_max * (1 - exp((-alpha * p) / etr_max)) + beta * p)
       }
 
       etr_regression_data <- create_regression_data(pars, predictions)
 
-      sdiff <- NA_real_
-      tryCatch(
-        {
-          sdiff <- calculate_sdiff(data, etr_regression_data, etr_type)
-        },
-        warning = function(w) {
-          walsby_message(paste("failed to calculate ik: warning:", w))
-        },
-        error = function(e) {
-          walsby_message(paste("failed to calculate ik: error:", e))
-        }
-      )
+      measured_predicted_etr_par_data <- get_etr_data_for_par_values(data, etr_regression_data, etr_type)
+
+      root_mean_squared_error <- root_mean_squared_error(measured_predicted_etr_par_data)
+
+      relative_root_mean_squared_error <- relative_root_mean_squared_error(measured_predicted_etr_par_data)
 
       result <- list(
         etr_type = etr_type,
         etr_regression_data = etr_regression_data,
-        sdiff = sdiff,
+        residual_sum_of_squares = residual_sum_of_squares,
+        root_mean_squared_error = root_mean_squared_error,
+        relative_root_mean_squared_error = relative_root_mean_squared_error,
         etr_max = etr_max,
         alpha = alpha,
         beta = beta
@@ -208,13 +207,15 @@ walsby_generate_regression_internal <- function(
 #'
 #' Enhances the Walsby (1997) model by adding parameters from other models and standardizing parameter names.
 #'
-#' @param model_result A list of model results including \code{etr_max}, \code{alpha}, and \code{beta}.
+#' @param model_result A list containing the model result (e.g. from walsby_generate_regression_ETR_II()).
 #'
 #' @return A list containing:
 #' \itemize{
 #'   \item \code{etr_type}: ETR Type based on the model result.
 #'   \item \code{etr_regression_data}: Regression data with ETR predictions based on the fitted model.
-#'   \item \code{sdiff}: The difference between observed and predicted ETR values.
+#'   \item \code{residual_sum_of_squares}: Difference between observed and predicted ETR values, expressed as the sum of squared residuals.
+#'   \item \code{root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the root mean squared error.
+#'   \item \code{relative_root_mean_squared_error}: Difference between observed and predicted ETR values, expressed as the relative root mean squared error, normalized by the mean.
 #'   \item \code{a}: Obtained parameter \code{a}, equal to \code{etrmax_without_photoinhibition}.
 #'   \item \code{b}: Obtained parameter \code{b}, equal to \code{alpha}.
 #'   \item \code{c}: Obtained parameter \code{c}, equal to \code{beta}.
@@ -253,7 +254,9 @@ walsby_modified <- function(model_result) {
   result <- create_modified_model_result(
     etr_type = get_etr_type_from_model_result(model_result),
     etr_regression_data = get_etr_regression_data_from_model_result(model_result),
-    sdiff = get_sdiff_from_model_result(model_result),
+    residual_sum_of_squares = get_sdiff_from_model_result(model_result),
+    model_result[["root_mean_squared_error"]],
+    model_result[["relative_root_mean_squared_error"]],
     a = model_result[["etr_max"]],
     b = model_result[["alpha"]],
     c = model_result[["beta"]],
