@@ -16,7 +16,7 @@ test_that("test-combo_plot_control 20240925.csv", {
       list("eilers_peeters", "platt", "walsby", "vollenweider"),
       list(color_eilers_peeters, color_platt, color_walsby, color_vollenweider)
     )
-    
-    ggplot2::ggsave("results/test_combo_plot_control.jpg", create.dir = TRUE, plot = plot, units = "px", width = 1000, height = 1600, dpi = 100, limitsize = FALSE)
+
+    ggplot2::ggsave("results/test_combo_plot_control_etr_I.jpg", create.dir = TRUE, plot = plot, units = "px", width = 1000, height = 2100, dpi = 100, limitsize = FALSE)
   })
 })
